==> jscsrc-guesser-0.3.0.tgz: package/lib/jscsrc-guesser.js <==
/**
 * Copyright 2015 Adrian Heine <mail@adrianheine.de>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

'use strict';

const Promise = require('es6-promise').Promise;

const getRules = require('./jscs-rules');
const runner = require('./jscs-runner');

module.exports = function (paths, config) {
  return getRules().then(function (rules) {
    const ruleValues = Object.keys(rules).reduce(function (ruleValues, ruleName) {
      return ruleValues.concat(rules[ruleName].getValues());
    }, []);
    const ruleSets = ruleValues.reduce(function (ruleSets, rule) {
      var targetRuleSet;
      for (var i = 0; i < ruleSets.length; ++i) {
        if (!ruleSets[i].hasOwnProperty(rule.ruleName)) {
          targetRuleSet = ruleSets[i];
        }
      }
      if (!targetRuleSet) {
        targetRuleSet = {};
        ruleSets.push(targetRuleSet);
      }
      targetRuleSet[rule.ruleName] = rule.value;
      return ruleSets;
    }, []);
    const promises = ruleSets.map(function (ruleSet) {
      return runner(ruleSet, config, paths).then(function (result) {
        const acceptedRuleValues = [];
        const rejectedRuleValues = [];
        Object.keys(ruleSet).forEach(function (ruleName) {
          const ruleValue = {
            name: ruleName,
            value: ruleSet[ruleName]
          };
          if (result.indexOf(ruleName) === -1) {
            acceptedRuleValues.push(ruleValue);
          } else {
            rejectedRuleValues.push(ruleValue);
          }
        });
        return [ acceptedRuleValues, rejectedRuleValues ];
      });
    });

    return Promise.all(promises).then(function (results) {
      var acceptedRuleValues = [];
      var rejectedRuleValues = [];
      results.forEach(function (result) {
        acceptedRuleValues = acceptedRuleValues.concat(result[0]);
        rejectedRuleValues = rejectedRuleValues.concat(result[1]);
      });

      const groupedConfig = acceptedRuleValues.reduce(function (groups, ruleValue) {
        if (!groups[ruleValue.name]) {
          groups[ruleValue.name] = [];
        }
        groups[ruleValue.name].push(ruleValue.value);
        return groups;
      }, {});

      const config = Object.keys(groupedConfig).reduce(function (config, ruleName) {
        const filteredValues = groupedConfig[ruleName].filter(function (value) {
          return rules[ruleName].filterValue(value, groupedConfig);
        });
        if (filteredValues.length > 0) {
          config[ruleName] = rules[ruleName].reduceValues(filteredValues);
        }
        return config;
      }, {});

      return {
        config: config,
        rejectedRuleValues: rejectedRuleValues
      };
    });
  });
};

==> jscsrc-guesser-0.5.0.tgz: package/lib/jscsrc-guesser.js <==
/**
 * Copyright 2015 Adrian Heine <mail@adrianheine.de>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

'use strict';

const Promise = require('es6-promise').Promise;

const getRules = require('./jscs-rules');
const runner = require('./jscs-runner');

module.exports = function (paths, config) {
  return getRules().then(function (rules) {
    const ruleValues = Object.keys(rules).reduce(function (ruleValues, ruleName) {
      return ruleValues.concat(rules[ruleName].getValues());
    }, []);
    const ruleSets = ruleValues.reduce(function (ruleSets, rule) {
      var targetRuleSet;
      for (var i = 0; i < ruleSets.length; ++i) {
        if (!ruleSets[i].hasOwnProperty(rule.ruleName)) {
          targetRuleSet = ruleSets[i];
        }
      }
      if (!targetRuleSet) {
        targetRuleSet = {};
        ruleSets.push(targetRuleSet);
      }
      targetRuleSet[rule.ruleName] = rule.value;
      return ruleSets;
    }, []);
    const promises = ruleSets.map(function (ruleSet) {
      return runner(ruleSet, config, paths).then(function (result) {
        const acceptedRuleValues = [];
        const rejectedRuleValues = [];
        Object.keys(ruleSet).forEach(function (ruleName) {
          const ruleValue = {
            name: ruleName,
            value: ruleSet[ruleName]
          };
          if (result.indexOf(ruleName) === -1) {
            acceptedRuleValues.push(ruleValue);
          } else {
            rejectedRuleValues.push(ruleValue);
          }
        });
        return [ acceptedRuleValues, rejectedRuleValues ];
      });
    });

    return Promise.all(promises).then(function (results) {
      var acceptedRuleValues = [];
      var rejectedRuleValues = [];
      results.forEach(function (result) {
        acceptedRuleValues = acceptedRuleValues.concat(result[0]);
        rejectedRuleValues = rejectedRuleValues.concat(result[1]);
      });

      const groupedConfig = acceptedRuleValues.reduce(function (groups, ruleValue) {
        if (!groups[ruleValue.name]) {
          groups[ruleValue.name] = [];
        }
        groups[ruleValue.name].push(ruleValue.value);
        return groups;
      }, {});

      const config = Object.keys(groupedConfig).reduce(function (config, ruleName) {
        const resultValue = rules[ruleName].filterAndReduceValues(
          groupedConfig[ruleName], groupedConfig);
        if (typeof resultValue !== 'undefined') {
          config[ruleName] = resultValue;
        }
        return config;
      }, {});

      return {
        config: config,
        rejectedRuleValues: rejectedRuleValues
      };
    });
  });
};
